@@ -127,6 +127,6 @@ def getwvTableForParent(access_token,subscription_key,rootUrl,activeOU,wellview,
                 "Ocp-Apim-Subscription-Key":subscription_key,
                 "wellview":wellview
                 }
-    url = F"{rootUrl}/{activeOU}/wellview/data/{table}/parentId/{parentId}?pagesize={pagesize}&cursor={cursor}"
+    url = F"{rootUrl}/{activeOU}/wellview/data/{table}/parentId/{parentId}?pagesize={pagesize}&cursor={cursor}&includecalcs=true&unitset=us"
     IDWELL = r.get(url=url,headers=call_headers)
     return IDWELL
